Compute group for stat_horizon
build_horizon_df_2(data, origin, horizonscale, rm.outliers, reverse, mirror)A data frame transformed for a horizon plot.
A data frame.
Origin of the horizon plot. It can either be a string, namely
"midpoint" (the default), "median",
"mean", "min" or "quantiles", or a user-specified number.
Cutpoints of the horizon plot. It can either be an integer
specifying the number of ranges (default is 6),
or a user-supplied numeric vector with the cutpoints defining the different ranges.
If TRUE, all the values below quantile(y, 0.25)-1.5*IQR(y)
and above quantile(y, 0.75)+1.5*IQR(y) are excluded from the origin and cutpoint
calculations (default is FALSE). @param reverse If TRUE, the horizon peaks
for the values below the origin are reversed (default is FALSE).
IF TRUE, the horizon peaks for all the values below the origin
are reversed (default is FALSE).
If TRUE, the horizon peaks for all the values are reversed
(default is FALSE).