hcl_generic: General color function
Description
General color function
Usage
hcl_generic(reverse, palette, ...)
Value
A function, that, given an integer, returns a character vector
of colors of the specified palette.
Arguments
- reverse
Logical, indicating whether the palette should be inverted.
- palette
A character string, indicating the palette to be used.